==> ideaIC-182.4323.18-sources.jar: git4idea/actions/GitShowCommitInLogAnnotationGutterActionProvider.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package git4idea.actions;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.vcs.VcsKey;
import com.intellij.openapi.vcs.annotate.AnnotationGutterActionProvider;
import com.intellij.openapi.vcs.annotate.FileAnnotation;
import com.intellij.openapi.vcs.annotate.UpToDateLineNumberListener;
import com.intellij.openapi.vcs.history.VcsRevisionNumber;
import git4idea.log.GitShowCommitInLogAction;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class GitShowCommitInLogAnnotationGutterActionProvider implements AnnotationGutterActionProvider {

  @NotNull
  @Override
  public AnAction createAction(@NotNull final FileAnnotation annotation) {
    return new MyShowCommitInLogAction(annotation);
  }

  private static class MyShowCommitInLogAction extends GitShowCommitInLogAction implements UpToDateLineNumberListener {
    private final FileAnnotation myAnnotation;
    private int myLineNumber;

    public MyShowCommitInLogAction(@NotNull FileAnnotation annotation) {
      myAnnotation = annotation;
    }

    @Nullable
    @Override
    protected VcsRevisionNumber getRevisionNumber(@NotNull AnActionEvent event) {
      return myAnnotation.getLineRevisionNumber(myLineNumber);
    }

    @Nullable
    @Override
    protected VcsKey getVcsKey(@NotNull AnActionEvent event) {
      return myAnnotation.getVcsKey();
    }

    @Override
    public void consume(Integer lineNumber) {
      myLineNumber = lineNumber;
    }
  }
}

==> ideaIC-2018.3.3-sources.jar: git4idea/actions/GitShowCommitInLogAnnotationGutterActionProvider.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package git4idea.actions;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.vcs.VcsKey;
import com.intellij.openapi.vcs.annotate.AnnotationGutterActionProvider;
import com.intellij.openapi.vcs.annotate.FileAnnotation;
import com.intellij.openapi.vcs.annotate.UpToDateLineNumberListener;
import com.intellij.openapi.vcs.history.VcsRevisionNumber;
import git4idea.log.GitShowCommitInLogAction;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class GitShowCommitInLogAnnotationGutterActionProvider implements AnnotationGutterActionProvider {

  @NotNull
  @Override
  public AnAction createAction(@NotNull final FileAnnotation annotation) {
    return new MyShowCommitInLogAction(annotation);
  }

  private static class MyShowCommitInLogAction extends GitShowCommitInLogAction implements UpToDateLineNumberListener {
    private final FileAnnotation myAnnotation;
    private int myLineNumber;

    MyShowCommitInLogAction(@NotNull FileAnnotation annotation) {
      myAnnotation = annotation;
    }

    @Nullable
    @Override
    protected VcsRevisionNumber getRevisionNumber(@NotNull AnActionEvent event) {
      return myAnnotation.getLineRevisionNumber(myLineNumber);
    }

    @Nullable
    @Override
    protected VcsKey getVcsKey(@NotNull AnActionEvent event) {
      return myAnnotation.getVcsKey();
    }

    @Override
    public void consume(Integer lineNumber) {
      myLineNumber = lineNumber;
    }
  }
}
